import StructuredData from '@/components/StructuredData';
import { Locales } from '@/locales/resources';
import { ldModule } from '@/server/ld';
import { metadataModule } from '@/server/metadata';
import { DiscoverService } from '@/server/services/discover';
import { translation } from '@/server/translation';
import { isMobileDevice } from '@/utils/responsive';
import Filescon from "./filescon";

import {Button} from "antd";


type Props = { searchParams: { hl?: Locales } };

export const generateMetadata = async ({ searchParams }: Props) => {
  const { t, locale } = await translation('metadata', searchParams?.hl);
  return metadataModule.generate({
    alternate: true,
    description: t('files.description'),
    locale,
    title: t('files.title'),
    url: '/files',
  });
};

const Page = async ({ searchParams }: Props) => {
  const { t, locale } = await translation('metadata', searchParams?.hl);
  const mobile = isMobileDevice();

  const discoverService = new DiscoverService();
  const items = await discoverService.getAssistantList(locale);

  const ld = ldModule.generate({
    description: t('files.description'),
    title: t('files.title'),
    url: '/files',
    webpage: {
      enable: true,
      search: '/files/search',
    },
  });

  return (
    <>
      <Filescon />
    </>
  );
};

Page.DisplayName = 'DiscoverAssistants';

export default Page;
